Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// LogLevel is the level of the logs to put out
LogLevel string `hcl:"log_level,optional"`
// DataDir is the directory to store our state in
DataDir string
// ProjectID
ProjectID string
// ProjectDir
ProjectDir string
// VagrantDir = DataDir + ProjectID
VagrantDir string
// Version information (set at compilation time)
Version *version.VersionInfo
}
Config contains configurations for the Seashell CLI
func DefaultConfig ¶
func DefaultConfig() *Config
DefaultConfig returns a Config struct populated with sane defaults
func (*Config) LoadFromFile ¶
LoadFromFile loads the configuration from a given path
Click to show internal directories.
Click to hide internal directories.